#!/bin/sh
# the next line restarts using wish \
exec wish8.3 "$0" "$@"


# Minimal example of a custom application using the wsurf widget.
#
# This example shows how to create a wsurf widget and how to add a 
# waveform pane, a time axis pane, and an empty visualization pane,
# where custom graphics can be put.


# Search for wsurf package in a reasonable location and load it
# This is for easy testing purposes when wsurf has not been installed

if {[llength [file split [info script]]] > 1} {
 # application called with whole pathname, use directory one level up
 set auto_path [concat [eval file join [lrange [file split [info script]] 0 end-2]] $auto_path]
} else {
 # application called with name and demos/ as working directory
 set auto_path [concat [file dirname [pwd]parent] $auto_path]
}
package require -exact wsurf 1.4



# Initialize wsurf package (this will set default preferences)

::wsurf::Initialize

# Make widget scroll during playback

set scroll Page
wsurf::SetPreference autoScroll $scroll



# Create and pack one wsurf widget

set widget [wsurf .ws -collapser 0]

pack $widget -expand 0 -fill both



# Add a couple of panes and some content from the standard plug-ins
# These lines have been copied from the standard Waveform configuration,
# ../wsurf1.4/configurations/Waveform.conf

set pane [$widget addPane -maxheight 2048  -minheight 10]
$widget analysis::addWaveform $pane

set pane [$widget addPane -maxheight 20  -minheight 20]
$widget timeaxis::addTimeAxis $pane

# Create a pane for custom drawing, keep track of its name in $myPane

set myPane [$widget addPane -height 100]



# Procedure that draws something in our pane (only)

proc Redraw {w pane} {
  if {$pane == $::myPane} {
    set c [$pane canvas]
    set width [expr {[$pane cget -maxtime] * [$pane cget -pixelspersecond]}]
    set height [$pane cget -scrollheight]
    $c delete all
    $c create line 0 0 $width $height
  }
}



# Register the "Redraw" procedure with the wsurf library.
# Every time the user zooms in or out with the wavebar "Redraw"
# will be called in order to update the contents of our pane.

wsurf::RegisterPlugin wsapp5 -redrawproc Redraw



# Prompt the user for a sound file, open it and draw something simple

proc Load {} {
  $::widget openFile [snack::getOpenFile]
  Redraw $::widget $::myPane
}



# Create some buttons at the bottom of the window

snack::createIcons

pack [button .a -image snackOpen -command Load] -side left

pack [checkbutton .b -text "Play scroll" -variable scroll \
      -onvalue Page -offvalue None \
      -command {wsurf::SetPreference autoScroll $scroll}] -side left
